api.currentuser.v1.test_helpers.picture package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.test_helpers.picture package

## Submodules

## api.currentuser.v1.test_helpers.picture.get_profile_picture module

`api.currentuser.v1.test_helpers.picture.get_profile_picture.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 403

`api.currentuser.v1.test_helpers.picture.get_profile_picture.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 404

`api.currentuser.v1.test_helpers.picture.get_profile_picture.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 200

`api.currentuser.v1.test_helpers.picture.get_profile_picture.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 401

## api.currentuser.v1.test_helpers.picture.update_profile_picture module

`api.currentuser.v1.test_helpers.picture.update_profile_picture.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 403

`api.currentuser.v1.test_helpers.picture.update_profile_picture.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 404

`api.currentuser.v1.test_helpers.picture.update_profile_picture.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 200

`api.currentuser.v1.test_helpers.picture.update_profile_picture.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 401

## Module contents